@@ -94,8 +94,21 @@ extern int iXAPitch;
 extern int iSPUIRQWait;
 extern int iUseTimer;
 
+static void ChangeWorkingDirectory(char *exe)
+{
+  s8 exepath[1024];
+  s8* s;
+  sprintf(exepath, "%s", exe);
+	s = strrchr(exepath, '/');
+	if (s != NULL) {
+		*s = '\0';
+		chdir(exepath);
+	}
+}
+
 int main(int argc, char *argv[])
 {
+	ChangeWorkingDirectory("c");
 	char file[MAXPATHLEN] = "";
 	char path[MAXPATHLEN];
 	const char *cdfile = NULL;
@@ -129,12 +142,12 @@ int main(int argc, char *argv[])
 	MAKE_PATH(Config.Mcd1, MEMCARD_DIR, "card1.mcd");
 	MAKE_PATH(Config.Mcd2, MEMCARD_DIR, "card2.mcd");
 	strcpy(Config.Bios, "HLE");
-	strcpy(Config.BiosDir, "./");
+	strcpy(Config.BiosDir, "/home/user/MyDocs");
 
 
 	Config.PsxAuto = 1;
 	
-	strcpy(Config.PluginsDir, "plugins");
+	strcpy(Config.PluginsDir, "/opt/maemo/usr/games/plugins");
 	strcpy(Config.Gpu, "builtin_gpu");
 	strcpy(Config.Spu, "builtin_spu");
 	strcpy(Config.Cdr, "builtin_cdr");
@@ -164,16 +177,26 @@ int main(int argc, char *argv[])
 			cdfile = isofilename;
 		}
 		else if (!strcmp(argv[i],"-frameskip")){
+		
+		int tv_reg=atol(argv[++i]);
+		if (tv_reg>0){
 		UseFrameSkip=1;
-		fFrameRateHz = Config.PsxType ? 50.0f : 59.94f;
+		fFrameRateHz = (tv_reg==1)?50.0f:  59.94f;
 		dwFrameRateTicks = (100000*100 / (unsigned long)(fFrameRateHz*100));
 		}
+		}
 		else if (!strcmp(argv[i],"-sputhreaded")){
 			iUseTimer=1;
 		}
 		else if (!strcmp(argv[i],"-nosound")){
 				strcpy(Config.Spu, "spunull.so");
 		}
+		else if (!strcmp(argv[i],"-bios")){
+		sprintf(Config.Bios, "/scph1001.bin");
+		}
+		else if (!strcmp(argv[i],"-gles")){
+		strcpy(Config.Gpu, "gpuGLES.so");
+		}
 		else if (!strcmp(argv[i], "-h") ||
 			 !strcmp(argv[i], "-help") ||
 			 !strcmp(argv[i], "--help")) {
@@ -207,7 +230,7 @@ int main(int argc, char *argv[])
 
 	
 	
-	snprintf(Config.PatchesDir, sizeof(Config.PatchesDir), "." PATCHES_DIR);
+	snprintf(Config.PatchesDir, sizeof(Config.PatchesDir), "/opt/maemo/usr/games" PATCHES_DIR);
 /*
 	// switch to plugin dotdir
 	// this lets plugins work without modification!
